@@ -1,7 +1,7 @@
 /*
  * libev native API header
  *
- * Copyright (c) 2007,2008,2009,2010 Marc Alexander Lehmann <libev@schmorp.de>
+ * Copyright (c) 2007,2008,2009,2010,2011 Marc Alexander Lehmann <libev@schmorp.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modifica-
@@ -193,11 +193,11 @@ struct ev_loop;
 /*****************************************************************************/
 
 #define EV_VERSION_MAJOR 4
-#define EV_VERSION_MINOR 0
+#define EV_VERSION_MINOR 3
 
 /* eventmask, revents, events... */
 enum {
-  EV_UNDEF    =         -1, /* guaranteed to be invalid */
+  EV_UNDEF    = 0xFFFFFFFF, /* guaranteed to be invalid */
   EV_NONE     =       0x00, /* no events */
   EV_READ     =       0x01, /* ev_io detected read will not block */
   EV_WRITE    =       0x02, /* ev_io detected write will not block */
@@ -491,7 +491,8 @@ enum {
 #if EV_COMPAT3
   EVFLAG_NOSIGFD   = 0, /* compatibility to pre-3.9 */
 #endif
-  EVFLAG_SIGNALFD  = 0x00200000U  /* attempt to use signalfd */
+  EVFLAG_SIGNALFD  = 0x00200000U, /* attempt to use signalfd */
+  EVFLAG_NOSIGMASK = 0x00400000U  /* avoid modifying the signal mask */
 };
 
 /* method bits to be ored together */
@@ -502,7 +503,8 @@ enum {
   EVBACKEND_KQUEUE  = 0x00000008U, /* bsd */
   EVBACKEND_DEVPOLL = 0x00000010U, /* solaris 8 */ /* NYI */
   EVBACKEND_PORT    = 0x00000020U, /* solaris 10 */
-  EVBACKEND_ALL     = 0x0000003FU
+  EVBACKEND_ALL     = 0x0000003FU, /* all known backends */
+  EVBACKEND_MASK    = 0x0000FFFFU  /* all future backends */
 };
 
 #if EV_PROTOTYPES
@@ -720,6 +722,7 @@ void ev_resume  (EV_P);
 void ev_feed_event     (EV_P_ void *w, int revents);
 void ev_feed_fd_event  (EV_P_ int fd, int revents);
 #if EV_SIGNAL_ENABLE
+void ev_feed_signal    (int signum);
 void ev_feed_signal_event (EV_P_ int signum);
 #endif
 void ev_invoke         (EV_P_ void *w, int revents);
@@ -809,9 +812,9 @@ void ev_async_send     (EV_P_ ev_async *w);
     EV_INLINE void ev_default_destroy (void) { ev_loop_destroy (EV_DEFAULT); }
     EV_INLINE void ev_default_fork    (void) { ev_loop_fork    (EV_DEFAULT); }
     #if EV_FEATURE_API
-      EV_INLINE void ev_loop_count  (EV_P) { ev_iteration  (EV_A); }
-      EV_INLINE void ev_loop_depth  (EV_P) { ev_depth      (EV_A); }
-      EV_INLINE void ev_loop_verify (EV_P) { ev_verify     (EV_A); }
+      EV_INLINE unsigned int ev_loop_count  (EV_P) { return ev_iteration  (EV_A); }
+      EV_INLINE unsigned int ev_loop_depth  (EV_P) { return ev_depth      (EV_A); }
+      EV_INLINE void         ev_loop_verify (EV_P) {        ev_verify     (EV_A); }
     #endif
   #endif
 #else
